html, body {
    width: 100%;
    height: 100%;
    background: #eee;
}

#app {
    margin-top: 20%;
}

form {
    opacity: 1.0;
    transition: opacity 1.0s;
}

#file-input {
    display: none;
}

#file-pick-label,
#file-repick-label,
#send-button,
#abort-button {
    transition: box-shadow 0.3s, background 0.3s;
    z-index: 1;
}

#send-button:hover {
    z-index: 0;
    box-shadow: 0 0 32px #0275D8;
}

#abort-button:hover {
    box-shadow: 0 0 32px #D9534F;
}

#file-repick-label:hover {
    z-index: 0;
    box-shadow: 0 0 32px #F0AD4E;
}

#file-pick-label:hover {
    box-shadow: 0 0 32px #7ABA25;
}

.fade-enter-active, .fade-leave-active {
  transition: opacity 1.5s
}

.fade-enter, .fade-leave-to {
  opacity: 0
}
